@@ -1,27 +1,25 @@
-/*
- * baobab-prefs.c
- * This file is part of baobab
+/* Copyright (C) 2005-2006 Fabio Marzocca <thesaltydog@gmail.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
- * Copyright (C) 2005-2006 Fabio Marzocca  <thesaltydog@gmail.com>
+ * This file is part of MATE Utils.
  *
- * This program is free software; you can redistribute it and/or modify
+ * MATE Utils is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * MATE Utils is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301  USA
+ * along with MATE Utils.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
 #include <string.h>
 #include <sys/stat.h>
@@ -35,6 +33,7 @@
 #include "baobab-prefs.h"
 
 #define BAOBAB_PREFERENCES_UI_RESOURCE "/org/mate/disk-usage-analyzer/baobab-dialog-scan-props.ui"
+#define GET_WIDGET(x) (GTK_WIDGET (gtk_builder_get_object (builder, (x))))
 
 enum
 {
@@ -162,7 +161,7 @@ create_tree_props (GtkBuilder *builder, GtkTreeModel *model)
 	GtkTreeViewColumn *col;
 	GtkWidget *tvw;
 
-	tvw = GTK_WIDGET (gtk_builder_get_object (builder , "tree_view_props"));
+	tvw = GET_WIDGET ("tree_view_props");
 
 	/* checkbox column */
 	cell = gtk_cell_renderer_toggle_new ();
@@ -294,7 +293,7 @@ baobab_prefs_dialog (void)
 		return;
 	}
 
-	dlg = GTK_WIDGET (gtk_builder_get_object (builder, "dialog_scan_props"));
+	dlg = GET_WIDGET ("dialog_scan_props");
 
 	gtk_window_set_transient_for (GTK_WINDOW (dlg),
 				      GTK_WINDOW (baobab.window));
@@ -312,7 +311,7 @@ baobab_prefs_dialog (void)
 	create_tree_props (builder, GTK_TREE_MODEL (model));
 	fill_props_model (model);
 
-	check_enablehome = GTK_WIDGET (gtk_builder_get_object (builder, "check_enable_home"));
+	check_enablehome = GET_WIDGET ("check_enable_home");
 	g_settings_bind (baobab.prefs_settings,
 			 BAOBAB_SETTINGS_MONITOR_HOME,
 			 check_enablehome, "active",
