@@ -1,27 +1,24 @@
-/*
- * callbacks.c
- * This file is part of baobab
+/* Copyright (C) 2005-2006 Fabio Marzocca <thesaltydog@gmail.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
- * Copyright (C) 2005-2006 Fabio Marzocca  <thesaltydog@gmail.com>
+ * This file is part of MATE Utils.
  *
- * This program is free software; you can redistribute it and/or modify
+ * MATE Utils is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 2 of the License, or
  * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * MATE Utils is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA  02110-1301  USA.
+ * along with MATE Utils.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 #include <string.h>
@@ -90,8 +87,7 @@ on_about_activate (GtkMenuItem *menuitem, gpointer user_data)
 		"General Public License for more details."),
 
 		N_("You should have received a copy of the GNU General Public License "
-		"along with this program; if not, write to the Free Software Foundation, Inc., 51 "
-		"Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.")
+		"along with this program.  If not, see <https://www.gnu.org/licenses/>.")
 	};
 
 
@@ -107,9 +103,9 @@ on_about_activate (GtkMenuItem *menuitem, gpointer user_data)
 		"program-name", _("Disk Usage Analyzer"),
 		"version", VERSION,
 		"title", _("About Disk Usage Analyzer"),
-		"comments", _("A graphical tool to analyze disk usage."),
+		"comments", _("Analyze your disk usage through a graphical tool."),
 		"copyright", _("Copyright \xc2\xa9 2005-2010 Fabio Marzocca\n"
-		               "Copyright \xc2\xa9 2011-2020 MATE developers"),
+		               "Copyright \xc2\xa9 2011-2021 MATE developers"),
 		"logo-icon-name", "mate-disk-usage-analyzer",
 		"license", license_trans,
 		"authors", authors,
