@@ -1,28 +1,25 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/*
- * MATE Search Tool
+/* Copyright (C) 2002 The Free Software Foundation
+ * Copyright (C) 2012-2021 MATE Developers
  *
- *  File:  gsearchtool-support.h
+ * This file is part of MATE Utils.
  *
- *  (C) 2002 the Free Software Foundation
+ * MATE Utils is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 2 of the License, or
+ * (at your option) any later version.
  *
- *  Authors:	Dennis Cranston  <dennis_cranston@yahoo.com>
- *		George Lebl
+ * MATE Utils is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with MATE Utils.  If not, see <https://www.gnu.org/licenses/>.
  *
+ * Authors:
+ *   Dennis Cranston <dennis_cranston@yahoo.com>
+ *   George Lebl
  */
 
 #ifndef _GSEARCHTOOL_SUPPORT_H_
@@ -68,11 +65,8 @@ gchar *
 remove_mnemonic_character (const gchar * string);
 
 gchar *
-get_readable_date (const CajaDateFormat date_format_enum,
-                   const time_t file_time_raw);
-gchar *
-gsearchtool_strdup_strftime (const gchar * format,
-                             struct tm * time_pieces);
+get_readable_date (const CajaDateFormat  date_format_enum,
+                   GDateTime            *file_time_raw);
 gchar *
 get_file_type_description (const gchar * file,
                            GFileInfo * file_info);
