@@ -1,27 +1,24 @@
-/* gdict-about.c - GtkAboutDialog wrapper
+/* Copyright (C) 2005 Emmanuele Bassi
+ * Copyright (C) 2012-2021 MATE Developers
  *
- * This file is part of MATE Dictionary
+ * This file is part of MATE Utils.
  *
- * Copyright (C) 2005 Emmanuele Bassi
+ * MATE Utils is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
+ * MATE Utils is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301, USA.
+ * along with MATE Utils.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #include <stdio.h>
@@ -54,7 +51,7 @@ gdict_show_about_dialog (GtkWidget *parent)
   };
 
   const gchar *translator_credits = _("translator-credits");
-  const gchar *comments = _("Look up words in dictionaries");
+  const gchar *comments = _("Look up words or terms in a dictionary source.");
 
   const gchar* license[] = {
     N_("This program is free software; you can redistribute it and/or "
@@ -68,9 +65,7 @@ gdict_show_about_dialog (GtkWidget *parent)
        "General Public License for more details."),
 
     N_("You should have received a copy of the GNU General Public License "
-       "along with this program; if not, write to the Free Software "
-       "Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA "
-       "02110-1301, USA.")
+       "along with this program.  If not, see <https://www.gnu.org/licenses/>.")
   };
 
   g_return_if_fail (GTK_IS_WIDGET (parent));
@@ -88,7 +83,7 @@ gdict_show_about_dialog (GtkWidget *parent)
   			 "version", VERSION,
 			 "title", _("About Dictionary"),
 			 "copyright", _("Copyright \xc2\xa9 2005-2006 Emmanuele Bassi\n"
-			                "Copyright \xc2\xa9 2011-2020 MATE developers"),
+			                "Copyright \xc2\xa9 2011-2021 MATE developers"),
   			 "comments", comments,
   			 "authors", authors,
   			 "documenters", documenters,
