@@ -1,27 +1,24 @@
-/* gdict-app.c - main application class
+/* Copyright (C) 2005 Emmanuele Bassi
+ * Copyright (C) 2012-2021 MATE Developers
  *
- * This file is part of MATE Dictionary
+ * This file is part of MATE Utils.
  *
- * Copyright (C) 2005 Emmanuele Bassi
+ * MATE Utils is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
+ * MATE Utils is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301, USA.
+ * along with MATE Utils.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #include <stdio.h>
@@ -345,7 +342,9 @@ gdict_init (int *argc, char ***argv)
   /* create the new option context */
   context = g_option_context_new (_(" - Look up words in dictionaries"));
 
+#ifdef ENABLE_NLS
   g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
+#endif /* ENABLE_NLS */
   g_option_context_add_main_entries (context, gdict_app_goptions, GETTEXT_PACKAGE);
   g_option_context_add_group (context, gdict_get_option_group ());
   g_option_context_add_group (context, gtk_get_option_group (TRUE));
