@@ -1,24 +1,24 @@
-/* gdict-applet.c - MATE Dictionary Applet
+/* Copyright (C) 2005 Emmanuele Bassi <ebassi@gmail.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
- * Copyright (c) 2005  Emmanuele Bassi <ebassi@gmail.com>
+ * This file is part of MATE Utils.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * MATE Utils is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * MATE Utils is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with MATE Utils.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #include <stdio.h>
@@ -96,16 +96,6 @@ struct _GdictAppletPrivate
 G_DEFINE_TYPE_WITH_PRIVATE (GdictApplet, gdict_applet, PANEL_TYPE_APPLET);
 
 
-static const GtkTargetEntry drop_types[] =
-{
-  { "text/plain",    0, 0 },
-  { "TEXT",          0, 0 },
-  { "STRING",        0, 0 },
-  { "UTF8_STRING",   0, 0 },
-};
-static const guint n_drop_types = G_N_ELEMENTS (drop_types);
-
-
 static void
 set_atk_name_description (GtkWidget  *widget,
 			  const char *name,
@@ -1177,7 +1167,7 @@ static const GtkActionEntry gdict_applet_menu_actions[] = {
   {"DictionarySave", "document-save", N_("_Save"),
     NULL, NULL,
     G_CALLBACK (gdict_applet_cmd_save) },
-  {"DictionaryPreferences", "preferences-desktop", N_("Preferences"),
+  {"DictionaryPreferences", "document-properties", N_("Preferences"),
     NULL, NULL,
     G_CALLBACK (gdict_applet_cmd_preferences) },
   {"DictionaryHelp", "help-browser", N_("_Help"),
@@ -1202,8 +1192,10 @@ gdict_applet_factory (MatePanelApplet *applet,
     {
       /* Set up the menu */
       priv->context_menu_action_group = gtk_action_group_new ("Dictionary Applet Actions");
+#ifdef ENABLE_NLS
       gtk_action_group_set_translation_domain(priv->context_menu_action_group,
                                               GETTEXT_PACKAGE);
+#endif /* ENABLE_NLS */
       gtk_action_group_add_actions(priv->context_menu_action_group,
 								gdict_applet_menu_actions,
 								G_N_ELEMENTS (gdict_applet_menu_actions),
