@@ -1,27 +1,24 @@
-/* gdict-pref-dialog.c - preferences dialog
+/* Copyright (C) 2005 Emmanuele Bassi
+ * Copyright (C) 2012-2021 MATE Developers
  *
- * This file is part of MATE Dictionary
+ * This file is part of MATE Utils.
  *
- * Copyright (C) 2005 Emmanuele Bassi
+ * MATE Utils is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
+ * MATE Utils is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301, USA.
+ * along with MATE Utils.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #include <stdio.h>
@@ -41,6 +38,7 @@
 #include "gdict-common.h"
 
 #define GDICT_PREFERENCES_UI 	PKGDATADIR "/mate-dictionary-preferences.ui"
+#define GET_WIDGET(x) (GTK_WIDGET (gtk_builder_get_object (dialog->builder, (x))))
 
 #define DEFAULT_MIN_WIDTH 	220
 #define DEFAULT_MIN_HEIGHT 	330
@@ -555,6 +553,7 @@ gdict_pref_dialog_set_property (GObject      *object,
       set_source_loader (dialog, g_value_get_object (value));
       break;
     default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
     }
 }
@@ -573,12 +572,14 @@ gdict_pref_dialog_get_property (GObject    *object,
       g_value_set_object (value, dialog->loader);
       break;
     default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
     }
 }
 
 static gboolean
-gdict_dialog_page_scroll_event_cb (GtkWidget *widget, GdkEventScroll *event, GtkWindow *window)
+on_preferences_notebook_scroll_event (GtkWidget      *widget,
+                                      GdkEventScroll *event)
 {
   GtkNotebook *notebook = GTK_NOTEBOOK (widget);
   GtkWidget *child, *event_widget, *action_widget;
@@ -600,39 +601,40 @@ gdict_dialog_page_scroll_event_cb (GtkWidget *widget, GdkEventScroll *event, Gtk
   if (event_widget == action_widget ||
       (action_widget != NULL && gtk_widget_is_ancestor (event_widget, action_widget)))
       return FALSE;
+
   action_widget = gtk_notebook_get_action_widget (notebook, GTK_PACK_END);
   if (event_widget == action_widget ||
       (action_widget != NULL && gtk_widget_is_ancestor (event_widget, action_widget)))
       return FALSE;
 
   switch (event->direction) {
-  case GDK_SCROLL_RIGHT:
-  case GDK_SCROLL_DOWN:
-    gtk_notebook_next_page (notebook);
-    break;
-  case GDK_SCROLL_LEFT:
-  case GDK_SCROLL_UP:
-    gtk_notebook_prev_page (notebook);
-    break;
-  case GDK_SCROLL_SMOOTH:
-    switch (gtk_notebook_get_tab_pos (notebook)) {
-    case GTK_POS_LEFT:
-    case GTK_POS_RIGHT:
-      if (event->delta_y > 0)
-          gtk_notebook_next_page (notebook);
-      else if (event->delta_y < 0)
-          gtk_notebook_prev_page (notebook);
+    case GDK_SCROLL_RIGHT:
+    case GDK_SCROLL_DOWN:
+      gtk_notebook_next_page (notebook);
       break;
-    case GTK_POS_TOP:
-    case GTK_POS_BOTTOM:
-      if (event->delta_x > 0)
-          gtk_notebook_next_page (notebook);
-      else if (event->delta_x < 0)
-          gtk_notebook_prev_page (notebook);
+    case GDK_SCROLL_LEFT:
+    case GDK_SCROLL_UP:
+      gtk_notebook_prev_page (notebook);
+      break;
+    case GDK_SCROLL_SMOOTH:
+      switch (gtk_notebook_get_tab_pos (notebook)) {
+        case GTK_POS_LEFT:
+        case GTK_POS_RIGHT:
+          if (event->delta_y > 0)
+            gtk_notebook_next_page (notebook);
+          else if (event->delta_y < 0)
+            gtk_notebook_prev_page (notebook);
+          break;
+        case GTK_POS_TOP:
+        case GTK_POS_BOTTOM:
+          if (event->delta_x > 0)
+            gtk_notebook_next_page (notebook);
+          else if (event->delta_x < 0)
+            gtk_notebook_prev_page (notebook);
+          break;
+      }
       break;
     }
-    break;
-  }
 
   return TRUE;
 }
@@ -690,40 +692,42 @@ gdict_pref_dialog_init (GdictPrefDialog *dialog)
 
   /* the main widget */
   gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
-                     GTK_WIDGET (gtk_builder_get_object (dialog->builder, "preferences_root")));
+                     GET_WIDGET ("preferences_root"));
 
   /* keep all the interesting widgets around */
-  dialog->notebook = GTK_WIDGET (gtk_builder_get_object (dialog->builder, "preferences_notebook"));
+  dialog->notebook = GET_WIDGET ("preferences_notebook");
 
   gtk_widget_add_events (dialog->notebook, GDK_SCROLL_MASK);
-  g_signal_connect (dialog->notebook, "scroll-event",
-                    G_CALLBACK (gdict_dialog_page_scroll_event_cb), GTK_WINDOW (dialog));
+  g_signal_connect (dialog->notebook,
+                    "scroll-event",
+                    G_CALLBACK (on_preferences_notebook_scroll_event),
+                    NULL);
 
-  dialog->sources_view = GTK_WIDGET (gtk_builder_get_object (dialog->builder, "sources_treeview"));
+  dialog->sources_view = GET_WIDGET ("sources_treeview");
   build_sources_view (dialog);
 
   dialog->active_source = g_settings_get_string (dialog->settings, GDICT_SETTINGS_SOURCE_KEY);
 
-  dialog->sources_add = GTK_WIDGET (gtk_builder_get_object (dialog->builder, "add_button"));
+  dialog->sources_add = GET_WIDGET ("add_button");
   gtk_widget_set_tooltip_text (dialog->sources_add,
                                _("Add a new dictionary source"));
   g_signal_connect (dialog->sources_add, "clicked",
   		    G_CALLBACK (source_add_clicked_cb), dialog);
 
-  dialog->sources_remove = GTK_WIDGET (gtk_builder_get_object (dialog->builder, "remove_button"));
+  dialog->sources_remove = GET_WIDGET ("remove_button");
   gtk_widget_set_tooltip_text (dialog->sources_remove,
                                _("Remove the currently selected dictionary source"));
   g_signal_connect (dialog->sources_remove, "clicked",
   		    G_CALLBACK (source_remove_clicked_cb), dialog);
 
-  dialog->sources_edit = GTK_WIDGET (gtk_builder_get_object (dialog->builder, "edit_button"));
+  dialog->sources_edit = GET_WIDGET ("edit_button");
   gtk_widget_set_tooltip_text (dialog->sources_edit,
                                _("Edit the currently selected dictionary source"));
   g_signal_connect (dialog->sources_edit, "clicked",
                     G_CALLBACK (source_edit_clicked_cb), dialog);
 
   font = g_settings_get_string (dialog->settings, GDICT_SETTINGS_PRINT_FONT_KEY);
-  dialog->font_button = GTK_WIDGET (gtk_builder_get_object (dialog->builder, "print_font_button"));
+  dialog->font_button = GET_WIDGET ("print_font_button");
   gtk_font_chooser_set_font (GTK_FONT_CHOOSER (dialog->font_button), font);
   gtk_widget_set_tooltip_text (dialog->font_button,
                                _("Set the font used for printing the definitions"));
