@@ -1,30 +1,28 @@
-/* mate-screenshot.c - Take a screenshot of the desktop
- *
- * Copyright (C) 2001 Jonathan Blandford <jrb@alum.mit.edu>
+/* Copyright (C) 2001 Jonathan Blandford <jrb@alum.mit.edu>
  * Copyright (C) 2006 Emmanuele Bassi <ebassi@gnome.org>
  * Copyright (C) 2008 Cosimo Cecchi <cosimoc@gnome.org>
+ * Copyright (C) 2012-2021 MATE Developers
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This file is part of MATE Utils.
  *
- * This program is distributed in the hope that it will be useful,
+ * MATE Utils is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * MATE Utils is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
- * USA
+ * along with MATE Utils.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-/* THERE ARE NO FEATURE REQUESTS ALLOWED */
-/* IF YOU WANT YOUR OWN FEATURE -- WRITE THE DAMN THING YOURSELF (-: */
-/* MAYBE I LIED... -jrb */
-
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
+
 #include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
 #include <sys/types.h>
@@ -34,7 +32,9 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <errno.h>
+#ifdef ENABLE_NLS
 #include <locale.h>
+#endif /* ENABLE_NLS */
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <pwd.h>
@@ -120,7 +120,7 @@ static GtkWidget *effect_label = NULL;
 static GtkWidget *effects_vbox = NULL;
 static GtkWidget *delay_hbox = NULL;
 
-void loop_dialog_screenshot ();
+void loop_dialog_screenshot (void);
 
 static void
 display_help (GtkWindow *parent)
@@ -1248,7 +1248,7 @@ screenshooter_init_stock_icons (void)
 }
 
 void
-loop_dialog_screenshot ()
+loop_dialog_screenshot (void)
 {
   /* interactive mode overrides everything */
   if (interactive_arg)
@@ -1324,10 +1324,12 @@ main (int argc, char *argv[])
     { NULL },
   };
 
+#ifdef ENABLE_NLS
   setlocale (LC_ALL, "");
   bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
+#endif /* ENABLE_NLS */
 
   context = g_option_context_new (_("Take a picture of the screen"));
   g_option_context_set_ignore_unknown_options (context, FALSE);
